summaryrefslogtreecommitdiff
path: root/file.h
diff options
context:
space:
mode:
Diffstat (limited to 'file.h')
-rw-r--r--file.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/file.h b/file.h
index 160bf4f..5889474 100644
--- a/file.h
+++ b/file.h
@@ -25,7 +25,8 @@ struct file
struct file *next;
char *name;
struct dep *deps;
- struct commands *cmds; /* Commands to execute for this target */
+ struct commands *cmds; /* Commands to execute for this target. */
+ int command_flags; /* Flags OR'd in for cmds; see commands.h. */
char *stem; /* Implicit stem, if an implicit
rule has been used */
struct dep *also_make; /* Targets that are made by making this. */